import { Fetch } from '@atproto-labs/fetch';
export type SafeFetchWrapOptions = NonNullable<Parameters<typeof safeFetchWrap>[0]>;
/**
 * Wrap a fetch function with safety checks so that it can be safely used
 * with user provided input (URL).
 *
 * @see {@link https://cheatsheetseries.owasp.org/cheatsheets/Server_Side_Request_Forgery_Prevention_Cheat_Sheet.html}
 */
export declare function safeFetchWrap({ fetch, responseMaxSize, // 512kB
ssrfProtection, allowCustomPort, allowData, allowHttp, allowIpHost, allowPrivateIps, timeout, forbiddenDomainNames, 
/**
 * When `false`, a {@link RequestInit['redirect']} value must be explicitly
 * provided or the request will fail.
 *
 * @default false
 */
allowImplicitRedirect, }?: {
    fetch?: Fetch | undefined;
    responseMaxSize?: number | undefined;
    ssrfProtection?: boolean | undefined;
    allowCustomPort?: boolean | undefined;
    allowData?: boolean | undefined;
    allowHttp?: boolean | undefined;
    allowIpHost?: boolean | undefined;
    allowPrivateIps?: boolean | undefined;
    timeout?: number | undefined;
    forbiddenDomainNames?: Iterable<string> | undefined;
    allowImplicitRedirect?: boolean | undefined;
}): (input: string | URL | Request, init?: RequestInit | undefined) => Promise<Response>;
//# sourceMappingURL=safe.d.ts.map